use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.19

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/Path/IsDev.pm',
    'lib/Path/IsDev/Heuristic/Changelog.pm',
    'lib/Path/IsDev/Heuristic/DevDirMarker.pm',
    'lib/Path/IsDev/Heuristic/META.pm',
    'lib/Path/IsDev/Heuristic/MYMETA.pm',
    'lib/Path/IsDev/Heuristic/Makefile.pm',
    'lib/Path/IsDev/Heuristic/TestDir.pm',
    'lib/Path/IsDev/Heuristic/Tool/Dzil.pm',
    'lib/Path/IsDev/Heuristic/Tool/MakeMaker.pm',
    'lib/Path/IsDev/Heuristic/Tool/ModuleBuild.pm',
    'lib/Path/IsDev/Heuristic/VCS/Git.pm',
    'lib/Path/IsDev/HeuristicSet/Basic.pm',
    'lib/Path/IsDev/NegativeHeuristic/HomeDir.pm',
    'lib/Path/IsDev/NegativeHeuristic/IsDev/IgnoreFile.pm',
    'lib/Path/IsDev/NegativeHeuristic/PerlINC.pm',
    'lib/Path/IsDev/Object.pm',
    'lib/Path/IsDev/Result.pm',
    'lib/Path/IsDev/Role/Heuristic.pm',
    'lib/Path/IsDev/Role/HeuristicSet.pm',
    'lib/Path/IsDev/Role/HeuristicSet/Simple.pm',
    'lib/Path/IsDev/Role/Matcher/Child/BaseName/MatchRegexp.pm',
    'lib/Path/IsDev/Role/Matcher/Child/BaseName/MatchRegexp/File.pm',
    'lib/Path/IsDev/Role/Matcher/Child/Exists/Any.pm',
    'lib/Path/IsDev/Role/Matcher/Child/Exists/Any/Dir.pm',
    'lib/Path/IsDev/Role/Matcher/Child/Exists/Any/File.pm',
    'lib/Path/IsDev/Role/Matcher/FullPath/Is/Any.pm',
    'lib/Path/IsDev/Role/NegativeHeuristic.pm',
    't/00-compile/lib_Path_IsDev_HeuristicSet_Basic_pm.t',
    't/00-compile/lib_Path_IsDev_Heuristic_Changelog_pm.t',
    't/00-compile/lib_Path_IsDev_Heuristic_DevDirMarker_pm.t',
    't/00-compile/lib_Path_IsDev_Heuristic_META_pm.t',
    't/00-compile/lib_Path_IsDev_Heuristic_MYMETA_pm.t',
    't/00-compile/lib_Path_IsDev_Heuristic_Makefile_pm.t',
    't/00-compile/lib_Path_IsDev_Heuristic_TestDir_pm.t',
    't/00-compile/lib_Path_IsDev_Heuristic_Tool_Dzil_pm.t',
    't/00-compile/lib_Path_IsDev_Heuristic_Tool_MakeMaker_pm.t',
    't/00-compile/lib_Path_IsDev_Heuristic_Tool_ModuleBuild_pm.t',
    't/00-compile/lib_Path_IsDev_Heuristic_VCS_Git_pm.t',
    't/00-compile/lib_Path_IsDev_NegativeHeuristic_HomeDir_pm.t',
    't/00-compile/lib_Path_IsDev_NegativeHeuristic_IsDev_IgnoreFile_pm.t',
    't/00-compile/lib_Path_IsDev_NegativeHeuristic_PerlINC_pm.t',
    't/00-compile/lib_Path_IsDev_Object_pm.t',
    't/00-compile/lib_Path_IsDev_Result_pm.t',
    't/00-compile/lib_Path_IsDev_Role_HeuristicSet_Simple_pm.t',
    't/00-compile/lib_Path_IsDev_Role_HeuristicSet_pm.t',
    't/00-compile/lib_Path_IsDev_Role_Heuristic_pm.t',
    't/00-compile/lib_Path_IsDev_Role_Matcher_Child_BaseName_MatchRegexp_File_pm.t',
    't/00-compile/lib_Path_IsDev_Role_Matcher_Child_BaseName_MatchRegexp_pm.t',
    't/00-compile/lib_Path_IsDev_Role_Matcher_Child_Exists_Any_Dir_pm.t',
    't/00-compile/lib_Path_IsDev_Role_Matcher_Child_Exists_Any_File_pm.t',
    't/00-compile/lib_Path_IsDev_Role_Matcher_Child_Exists_Any_pm.t',
    't/00-compile/lib_Path_IsDev_Role_Matcher_FullPath_Is_Any_pm.t',
    't/00-compile/lib_Path_IsDev_Role_NegativeHeuristic_pm.t',
    't/00-compile/lib_Path_IsDev_pm.t',
    't/00-report-prereqs.dd',
    't/00-report-prereqs.t',
    't/Path-IsDev-Object/_matches.t',
    't/Path-IsDev-Object/basic.t',
    't/Path-IsDev/is_dev/Changelog.t',
    't/Path-IsDev/is_dev/DZil.t',
    't/Path-IsDev/is_dev/DevDir.t',
    't/Path-IsDev/is_dev/META.t',
    't/Path-IsDev/is_dev/MYMETA.t',
    't/Path-IsDev/is_dev/MakeMaker.t',
    't/Path-IsDev/is_dev/ModuleBuild.t',
    't/Path-IsDev/is_dev/TestDir.t',
    't/Path-IsDev/is_dev/suite.t.tpl',
    't/basic.t'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
